#!/usr/bin/env bash
#
# Convert one or more Max patches, replacing every instance of
# "az." with "az1.". This is to make it work with the auzzie1 compatibility
# Max package. Each new file has the same name as the old file, but with
# "-converted" appended before the final dot. The script will refuse to
# write this file, if there is already a file by that name in the directory.
#
# Note that some patches will refer to an "auzzie" directory within the
# user's Max package folder, and this should no longer exist after 
# installing the auzzie1 package. (Though we rely on the user to delete
# the "auzzie" package.) This does not matter, as those are simply the
# "dependency paths" cached in the .maxpat file. If they don't exist,
# they will be regenerated. So we don't bother to convert those.
# If you really wanted to convert them, you could add another line to
# the sed argument list:
#   -e 's/auzzie/auzzie1/g' \
# before the final output redirection line.

echo
echo
if [ "$1" != "" ]; then
	echo You dropped $@
else
	echo You dropped nothing
fi
echo

for file in "$@"
do
	if [ ! -e $file ]
	then
		echo "Can't find input file."
		exit 1
	fi
	base=`expr "$file" : '\(.*\)\..*'`
	ext=`expr "$file" : '.*\.\(.*\)'`
	if [ $ext != "maxpat" ]
	then
		echo "Input file must end with \".maxpat\"."
		exit 1
	fi
	outfile=${base}-converted.${ext}
	if [ -e "$outfile" ]
	then
		echo "Output file \"${outfile}\" already exists. Delete it first."
		exit 1
	fi
	sed \
	-e 's/az\./az1\./g' \
	$file > "$outfile"
done
exit 0

